Developer documentation
***********************

This section of the documentation is meant for those who wish to contribute to
the Girder Worker platform.

.. _install-from-source:

Installing from source
======================

Testing Infrastructure
======================

Creating a new release
======================


.. _task-plugins:
